Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .cls import TypedConfig, TypedMapping, TypedMutableMapping, update

9 from .core import (

10 all_annotations,

11 check_and_convert_data,

12 convert_config,

13 ensure_types,

14 load_into,

15 load_into_class,

16 load_into_instance,

17)

18 from .dump import asdict, asjson, astoml, asyaml

19 from .postpone import postpone

20 from .singleton import Singleton, SingletonMeta

21

22 __all__ = [

23 # cls

24 "TypedConfig",

25 "TypedMapping",

26 "TypedMutableMapping",

27 "update",

28 # singleton

29 "Singleton",

30 "SingletonMeta",

31 # core

32 "all_annotations",

33 "check_and_convert_data",

34 "convert_config",

35 "ensure_types",

36 "load_into",

37 "load_into_class",

38 "load_into_instance",

39 # postpone

40 "postpone",

41 # dump

42 "asdict",

43 "astoml",

44 "asyaml",

45 "asjson",

46]